.. _api_elem_valuerep:

Specialized Element Value Representation (:mod:`pydicom.valuerep`)
==================================================================

.. currentmodule:: pydicom.valuerep

Representation of the value for data elements with VR of PN, DS, IS, DA, DT
or TM and utilities.

.. autosummary::
   :toctree: generated/

   DA
   DS
   DSdecimal
   DSfloat
   DT
   IS
   MultiString
   PersonName
   PersonNameUnicode
   TM
